# Changelog

## [0.5.0](https://github.com/imnotjames/pyawful/compare/v0.4.0...v0.5.0) (2024-12-13)


### Features

* add error handling for common situations ([28da16f](https://github.com/imnotjames/pyawful/commit/28da16f7655db0e35301ac966fd8b40acd95f8a4))

## [0.4.0](https://github.com/imnotjames/pyawful/compare/v0.3.0...v0.4.0) (2024-12-08)


### Features

* support parsing page info from thread parsing ([95f9bcc](https://github.com/imnotjames/pyawful/commit/95f9bcc7fe70005976f0a8a1dd192b8e00de77cc))


### Bug Fixes

* properly get user ID from rap sheet link ([1404325](https://github.com/imnotjames/pyawful/commit/14043256c629de9e6738eae717bd305b8c5368a2))

## [0.3.0](https://github.com/imnotjames/pyawful/compare/v0.2.0...v0.3.0) (2024-12-08)


### Features

* support re-using session cookies ([51cc3d9](https://github.com/imnotjames/pyawful/commit/51cc3d9dee69392d84d74748fcf313eb7ceac779))


### Bug Fixes

* better error handling for parser ([e63b59e](https://github.com/imnotjames/pyawful/commit/e63b59eee91d5a7293704de32e5217e16bf0998b))
* corrected usage of cookies with typing ([76e07c8](https://github.com/imnotjames/pyawful/commit/76e07c808e878d958898ace18ea7a2457816025b))


### Documentation

* slightly more correct usage example ([8ee40fa](https://github.com/imnotjames/pyawful/commit/8ee40fa2f7529dffcb7a5fe008dbd74d62973303))

## [0.2.0](https://github.com/imnotjames/pyawful/compare/v0.1.1...v0.2.0) (2024-12-08)


### Features

* support user profiles ([f4cbdef](https://github.com/imnotjames/pyawful/commit/f4cbdef7e0371817030e6c075c9307778a7771cb))


### Bug Fixes

* move auth into the awful client rather than the network client ([dd89a62](https://github.com/imnotjames/pyawful/commit/dd89a627705e9f8ca42118c8e724910157244d40))


### Documentation

* reference correct package name ([2602706](https://github.com/imnotjames/pyawful/commit/2602706ce2f6c846a0ae5b8434b00223ceb6f58b))

## [0.1.1](https://github.com/imnotjames/pyawful/compare/v0.1.0...v0.1.1) (2024-12-08)


### Bug Fixes

* proper forum thread sort ([c31e385](https://github.com/imnotjames/pyawful/commit/c31e3850e7a30820a1e5a3c7e1cc274e5a197aa1))

## [0.1.0](https://github.com/imnotjames/pyawful/compare/v0.0.1...v0.1.0) (2024-12-07)


### Features

* add SAD abbrev ([cb2bfa1](https://github.com/imnotjames/pyawful/commit/cb2bfa1741e944db2e19e1479e1f1b8e98316abf))
* initial commit of the somethingawful library ([9f0a373](https://github.com/imnotjames/pyawful/commit/9f0a3736874ef18062c64f1abee08a40027a6b65))


### Bug Fixes

* drop registration date from user so we can reference them more ([6e3f0e6](https://github.com/imnotjames/pyawful/commit/6e3f0e6095876b8e8eeb20cfc924345c9028efbe))


### Documentation

* add example usage to readme ([ba7fb6a](https://github.com/imnotjames/pyawful/commit/ba7fb6ad7df08f32776312c2d132cbbb1972dc43))
